@@ -18,6 +18,8 @@ def manage(*args):
     app = loadapp('config:%s' % config)
     from django.core import management
     management.setup_environ = lambda *args: os.getcwd
+    loadapp('config:%s' % config)
+    from django.core.management import execute_manager
     from django.conf import settings as sets
     sys.argv[1:1] = args
     management.execute_manager(settings)
